@@ -454,15 +454,15 @@ impl Default for KEHelpPopup {
                         .add_col(TextSpan::new("Key input").bold().fg(Color::LightYellow))
                         .add_row()
                         .add_col(TextSpan::new("").bold().fg(Color::Cyan))
-                        .add_col(TextSpan::from("You can input 1 char, or specail key name."))
+                        .add_col(TextSpan::from("You can input 1 char, or key name."))
                         .add_row()
-                        .add_col(TextSpan::new("<Supported Key Name>").bold().fg(Color::Cyan))
+                        .add_col(TextSpan::new("<Key Name>").bold().fg(Color::Cyan))
                         .add_col(TextSpan::from("backspace/enter/left/right/up/down"))
                         .add_row()
-                        .add_col(TextSpan::new("<Supported Key Name>").bold().fg(Color::Cyan))
+                        .add_col(TextSpan::new("<Key Name>").bold().fg(Color::Cyan))
                         .add_col(TextSpan::from("home/end/pageup/pagedown/tab/backtab"))
                         .add_row()
-                        .add_col(TextSpan::new("<Supported Key Name>").bold().fg(Color::Cyan))
+                        .add_col(TextSpan::new("<Key Name>").bold().fg(Color::Cyan))
                         .add_col(TextSpan::from("delete/insert/esc"))
                         .build(),
                 ),
